@@ -18,7 +18,8 @@ import re
 from . import build, environment
 from .backend.backends import InstallData
 from .mesonlib import (MesonException, Popen_safe, RealPathAction, is_windows,
-                       is_aix, setup_vsenv, pickle_load, is_osx, OptionKey)
+                       is_aix, setup_vsenv, pickle_load, is_osx)
+from .options import OptionKey
 from .scripts import depfixer, destdir_join
 from .scripts.meson_exe import run_exe
 try:
@@ -73,11 +74,11 @@ def add_arguments(parser: argparse.ArgumentParser) -> None:
                         help='Do not rebuild before installing.')
     parser.add_argument('--only-changed', default=False, action='store_true',
                         help='Only overwrite files that are older than the copied file.')
-    parser.add_argument('--quiet', default=False, action='store_true',
+    parser.add_argument('-q', '--quiet', default=False, action='store_true',
                         help='Do not print every file that was installed.')
     parser.add_argument('--destdir', default=None,
                         help='Sets or overrides DESTDIR environment. (Since 0.57.0)')
-    parser.add_argument('--dry-run', '-n', action='store_true',
+    parser.add_argument('-n', '--dry-run', action='store_true',
                         help='Doesn\'t actually install, but print logs. (Since 0.57.0)')
     parser.add_argument('--skip-subprojects', nargs='?', const='*', default='',
                         help='Do not install files from given subprojects. (Since 0.58.0)')
@@ -148,23 +149,29 @@ def set_chown(path: str, user: T.Union[str, int, None] = None,
     # be actually passed properly.
     # Not nice, but better than actually rewriting shutil.chown until
     # this python bug is fixed: https://bugs.python.org/issue18108
-    real_os_chown = os.chown
 
-    def chown(path: T.Union[int, str, 'os.PathLike[str]', bytes, 'os.PathLike[bytes]'],
-              uid: int, gid: int, *, dir_fd: T.Optional[int] = dir_fd,
-              follow_symlinks: bool = follow_symlinks) -> None:
-        """Override the default behavior of os.chown
+    if sys.version_info >= (3, 13):
+        # pylint: disable=unexpected-keyword-arg
+        # cannot handle sys.version_info, https://github.com/pylint-dev/pylint/issues/9622
+        shutil.chown(path, user, group, dir_fd=dir_fd, follow_symlinks=follow_symlinks)
+    else:
+        real_os_chown = os.chown
 
-        Use a real function rather than a lambda to help mypy out. Also real
-        functions are faster.
-        """
-        real_os_chown(path, uid, gid, dir_fd=dir_fd, follow_symlinks=follow_symlinks)
+        def chown(path: T.Union[int, str, 'os.PathLike[str]', bytes, 'os.PathLike[bytes]'],
+                  uid: int, gid: int, *, dir_fd: T.Optional[int] = dir_fd,
+                  follow_symlinks: bool = follow_symlinks) -> None:
+            """Override the default behavior of os.chown
 
-    try:
-        os.chown = chown
-        shutil.chown(path, user, group)
-    finally:
-        os.chown = real_os_chown
+            Use a real function rather than a lambda to help mypy out. Also real
+            functions are faster.
+            """
+            real_os_chown(path, uid, gid, dir_fd=dir_fd, follow_symlinks=follow_symlinks)
+
+        try:
+            os.chown = chown
+            shutil.chown(path, user, group)
+        finally:
+            os.chown = real_os_chown
 
 
 def set_chmod(path: str, mode: int, dir_fd: T.Optional[int] = None,
@@ -557,7 +564,12 @@ class Installer:
             if is_windows() or destdir != '' or not os.isatty(sys.stdout.fileno()) or not os.isatty(sys.stderr.fileno()):
                 # can't elevate to root except in an interactive unix environment *and* when not doing a destdir install
                 raise
-            rootcmd = os.environ.get('MESON_ROOT_CMD') or shutil.which('sudo') or shutil.which('doas')
+            rootcmd = (
+                os.environ.get('MESON_ROOT_CMD')
+                or shutil.which('sudo')
+                or shutil.which('doas')
+                or shutil.which('run0')
+            )
             pkexec = shutil.which('pkexec')
             if rootcmd is None and pkexec is not None and 'PKEXEC_UID' not in os.environ:
                 rootcmd = pkexec
